import { Prop, Provide, Emit, Model } from 'vue-property-decorator';
import { Subject, Subscription } from 'rxjs';
import { Watch, EditFormControlBase } from '@/studio-core';
import SalesOrderService from '@/service/sales-order/sales-order-service';
import InfoService from './info-form-service';
import { FormButtonModel, FormPageModel, FormItemModel, FormDRUIPartModel, FormPartModel, FormGroupPanelModel, FormIFrameModel, FormRowItemModel, FormTabPageModel, FormTabPanelModel, FormUserControlModel } from '@/model/form-detail';


/**
 * form部件基类
 *
 * @export
 * @class EditFormControlBase
 * @extends {InfoEditFormBase}
 */
export class InfoEditFormBase extends EditFormControlBase {

    /**
     * 建构部件服务对象
     *
     * @type {InfoService}
     * @memberof InfoEditFormBase
     */
    public service: InfoService = new InfoService({ $store: this.$store });

    /**
     * 实体服务对象
     *
     * @type {SalesOrderService}
     * @memberof InfoEditFormBase
     */
    public appEntityService: SalesOrderService = new SalesOrderService({ $store: this.$store });

    /**
     * 应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof InfoEditFormBase
     */
    protected appDeName: string = 'salesorder';

    /**
     * 表单数据对象
     *
     * @type {*}
     * @memberof InfoEditFormBase
     */
    public data: any = {
        srfupdatedate: null,
        srforikey: null,
        srfkey: null,
        srfmajortext: null,
        srftempmode: null,
        srfuf: null,
        srfdeid: null,
        srfsourcekey: null,
        ordernumber: null,
        salesordername: null,
        transactioncurrencyname: null,
        pricelevelname: null,
        requestdeliveryby: null,
        shippingmethodcode: null,
        paymenttermscode: null,
        freighttermscode: null,
        description: null,
        opportunityname: null,
        quotename: null,
        customerid: null,
        billto_country: null,
        billto_stateorprovince: null,
        billto_city: null,
        billto_line1: null,
        billto_postalcode: null,
        salesorderid: null,
        salesorder:null,
    };

    /**
     * 属性值规则
     *
     * @type {*}
     * @memberof InfoEditFormBase
     */
    public rules: any = {
        srfupdatedate: [
            { required: false, type: 'string', message: '更新时间 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '更新时间 值不能为空', trigger: 'blur' },
        ],
        srforikey: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        srfkey: [
            { required: false, type: 'string', message: '订单 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '订单 值不能为空', trigger: 'blur' },
        ],
        srfmajortext: [
            { required: false, type: 'string', message: '销售订单名称 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '销售订单名称 值不能为空', trigger: 'blur' },
        ],
        srftempmode: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        srfuf: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        srfdeid: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        srfsourcekey: [
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: ' 值不能为空', trigger: 'blur' },
        ],
        ordernumber: [
            { required: false, type: 'string', message: '订单编码 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '订单编码 值不能为空', trigger: 'blur' },
        ],
        salesordername: [
            { required: false, type: 'string', message: '销售订单名称 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '销售订单名称 值不能为空', trigger: 'blur' },
        ],
        transactioncurrencyname: [
            { required: false, type: 'string', message: '货币 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '货币 值不能为空', trigger: 'blur' },
        ],
        pricelevelname: [
            { required: false, type: 'string', message: '价目表 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '价目表 值不能为空', trigger: 'blur' },
        ],
        requestdeliveryby: [
            { required: false, type: 'string', message: '要求交付日期 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '要求交付日期 值不能为空', trigger: 'blur' },
        ],
        shippingmethodcode: [
            { required: false, type: 'string', message: '送货方式 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '送货方式 值不能为空', trigger: 'blur' },
        ],
        paymenttermscode: [
            { required: false, type: 'string', message: '付款条件 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '付款条件 值不能为空', trigger: 'blur' },
        ],
        freighttermscode: [
            { required: false, type: 'string', message: '货运条款 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '货运条款 值不能为空', trigger: 'blur' },
        ],
        description: [
            { required: false, type: 'string', message: '说明 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '说明 值不能为空', trigger: 'blur' },
        ],
        opportunityname: [
            { required: false, type: 'string', message: '商机 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '商机 值不能为空', trigger: 'blur' },
        ],
        quotename: [
            { required: false, type: 'string', message: '报价单 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '报价单 值不能为空', trigger: 'blur' },
        ],
        customerid: [
            { required: false, type: 'string', message: '客户 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '客户 值不能为空', trigger: 'blur' },
        ],
        billto_country: [
            { required: false, type: 'string', message: '国家/地区 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '国家/地区 值不能为空', trigger: 'blur' },
        ],
        billto_stateorprovince: [
            { required: false, type: 'string', message: '省/市/自治区 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '省/市/自治区 值不能为空', trigger: 'blur' },
        ],
        billto_city: [
            { required: false, type: 'string', message: '市/县 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '市/县 值不能为空', trigger: 'blur' },
        ],
        billto_line1: [
            { required: false, type: 'string', message: '街道 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '街道 值不能为空', trigger: 'blur' },
        ],
        billto_postalcode: [
            { required: false, type: 'string', message: '邮政编码 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '邮政编码 值不能为空', trigger: 'blur' },
        ],
        salesorderid: [
            { required: false, type: 'string', message: '订单 值不能为空', trigger: 'change' },
            { required: false, type: 'string', message: '订单 值不能为空', trigger: 'blur' },
        ],
    }

    /**
     * 详情模型集合
     *
     * @type {*}
     * @memberof InfoEditFormBase
     */
    public detailsModel: any = {
        group1: new FormGroupPanelModel({ caption: '基本信息', detailType: 'GROUPPANEL', name: 'group1', visible: true, isShowCaption: true, form: this, uiActionGroup: { caption: '', langbase: 'entities.salesorder.info_form', extractMode: 'ITEM', details: [] } }),

        grouppanel1: new FormGroupPanelModel({ caption: '详细信息', detailType: 'GROUPPANEL', name: 'grouppanel1', visible: true, isShowCaption: true, form: this, uiActionGroup: { caption: '', langbase: 'entities.salesorder.info_form', extractMode: 'ITEM', details: [] } }),

        grouppanel3: new FormGroupPanelModel({ caption: '销售信息', detailType: 'GROUPPANEL', name: 'grouppanel3', visible: true, isShowCaption: true, form: this, uiActionGroup: { caption: '', langbase: 'entities.salesorder.info_form', extractMode: 'ITEM', details: [] } }),

        grouppanel2: new FormGroupPanelModel({ caption: '帐单地址', detailType: 'GROUPPANEL', name: 'grouppanel2', visible: true, isShowCaption: true, form: this, uiActionGroup: { caption: '', langbase: 'entities.salesorder.info_form', extractMode: 'ITEM', details: [] } }),

        formpage1: new FormPageModel({ caption: '基本信息', detailType: 'FORMPAGE', name: 'formpage1', visible: true, isShowCaption: true, form: this }),

        srfupdatedate: new FormItemModel({ caption: '更新时间', detailType: 'FORMITEM', name: 'srfupdatedate', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 0 }),

        srforikey: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srforikey', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srfkey: new FormItemModel({ caption: '订单', detailType: 'FORMITEM', name: 'srfkey', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 1 }),

        srfmajortext: new FormItemModel({ caption: '销售订单名称', detailType: 'FORMITEM', name: 'srfmajortext', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srftempmode: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srftempmode', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srfuf: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srfuf', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srfdeid: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srfdeid', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        srfsourcekey: new FormItemModel({ caption: '', detailType: 'FORMITEM', name: 'srfsourcekey', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        ordernumber: new FormItemModel({ caption: '订单编码', detailType: 'FORMITEM', name: 'ordernumber', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 1 }),

        salesordername: new FormItemModel({ caption: '销售订单名称', detailType: 'FORMITEM', name: 'salesordername', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        transactioncurrencyname: new FormItemModel({ caption: '货币', detailType: 'FORMITEM', name: 'transactioncurrencyname', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        pricelevelname: new FormItemModel({ caption: '价目表', detailType: 'FORMITEM', name: 'pricelevelname', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        requestdeliveryby: new FormItemModel({ caption: '要求交付日期', detailType: 'FORMITEM', name: 'requestdeliveryby', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        shippingmethodcode: new FormItemModel({ caption: '送货方式', detailType: 'FORMITEM', name: 'shippingmethodcode', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        paymenttermscode: new FormItemModel({ caption: '付款条件', detailType: 'FORMITEM', name: 'paymenttermscode', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        freighttermscode: new FormItemModel({ caption: '货运条款', detailType: 'FORMITEM', name: 'freighttermscode', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        description: new FormItemModel({ caption: '说明', detailType: 'FORMITEM', name: 'description', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        opportunityname: new FormItemModel({ caption: '商机', detailType: 'FORMITEM', name: 'opportunityname', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        quotename: new FormItemModel({ caption: '报价单', detailType: 'FORMITEM', name: 'quotename', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        customerid: new FormItemModel({ caption: '客户', detailType: 'FORMITEM', name: 'customerid', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        billto_country: new FormItemModel({ caption: '国家/地区', detailType: 'FORMITEM', name: 'billto_country', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        billto_stateorprovince: new FormItemModel({ caption: '省/市/自治区', detailType: 'FORMITEM', name: 'billto_stateorprovince', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        billto_city: new FormItemModel({ caption: '市/县', detailType: 'FORMITEM', name: 'billto_city', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        billto_line1: new FormItemModel({ caption: '街道', detailType: 'FORMITEM', name: 'billto_line1', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        billto_postalcode: new FormItemModel({ caption: '邮政编码', detailType: 'FORMITEM', name: 'billto_postalcode', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 3 }),

        salesorderid: new FormItemModel({ caption: '订单', detailType: 'FORMITEM', name: 'salesorderid', visible: true, isShowCaption: true, form: this, disabled: false, enableCond: 1 }),

    };
}